@@ -19,7 +19,7 @@ class Gchart
   end
 
   def self.types
-    @types ||= ['line', 'line_xy', 'scatter', 'bar', 'venn', 'pie', 'pie_3d', 'jstize', 'sparkline', 'meter', 'map', 'radar']
+    @types ||= ['line', 'line_xy', 'scatter', 'bar', 'venn', 'pie', 'pie_3d', 'pie_c', 'jstize', 'sparkline', 'meter', 'map', 'radar']
   end
 
   def self.simple_chars
@@ -38,14 +38,14 @@ class Gchart
     'chart.png'
   end
 
-  attr_accessor :title, :type, :width, :height, :curved, :horizontal, :grouped, :legend, :legend_position, :labels, :data, :encoding, :bar_colors,
-  :title_color, :title_size, :title_alignment, :custom, :axis_with_labels, :axis_labels, :bar_width_and_spacing, :id, :alt, :klass,
+  attr_accessor :title, :type, :width, :height, :curved, :horizontal, :grouped, :overlapped, :legend, :legend_position, :labels, :data, :encoding, :bar_colors,
+  :title_color, :title_size, :title_alignment, :custom, :axis_with_labels, :custom_axis_with_labels, :axis_labels, :bar_width_and_spacing, :id, :alt, :klass,
   :range_markers, :geographical_area, :map_colors, :country_codes, :axis_range, :filename, :min, :max, :colors, :usemap
 
   attr_accessor :bg_type, :bg_color, :bg_angle, :chart_type, :chart_color, :chart_angle, :axis_range, :thickness, :new_markers, :grid_lines, :use_ssl
 
   attr_accessor :min_value, :max_value
-  
+
   types.each do |type|
     instance_eval <<-DYNCLASSMETH
     def #{type}(options = {})
@@ -73,13 +73,21 @@ class Gchart
   end
 
   def initialize(options={})
+    # Allow Gchart to take a theme too
+    @theme = options[:theme] 
+    options = @theme ? Chart::Theme.load(@theme).to_options.merge(options) : options
+    options.delete(:theme)
+
     @type = options[:type] || 'line'
     @data = []
     @width = 300
     @height = 200
     @curved = false
     @horizontal = false
+
     @grouped = false
+    @overlapped = false
+
     @use_ssl = false
     @encoding = 'simple'
     # @max_value = 'auto'
@@ -106,11 +114,11 @@ class Gchart
   def size=(size='300x200')
     @width, @height = size.split("x").map { |dimension| dimension.to_i }
   end
-  
+
   def size
     "#{width}x#{height}"
   end
-  
+
   def dimensions
     # TODO: maybe others?
     [:line_xy, :scatter].include?(type) ? 2 : 1
@@ -125,9 +133,14 @@ class Gchart
     end
   end
 
-  # Sets the bar graph presentation (stacked or grouped)
-  def stacked=(option=true)
-    @grouped = option ? false : true
+  def bar_presentation
+    if @overlapped
+      'o'
+    elsif @grouped
+      'g'
+    else
+      's'
+    end
   end
 
   def bg=(options)
@@ -149,7 +162,7 @@ class Gchart
       @chart_angle = options[:angle]
     end
   end
-  
+
   def max_value=(max_v)
     if max_v =~ /false/
       @max_value = false
@@ -174,7 +187,7 @@ class Gchart
     ds.each_with_index do |mds, mds_index|
       mds[:min_value] ||= min_value
       mds[:max_value] ||= max_value
-      
+
       if mds_index == 0 && type.to_s == 'bar'
         # TODO: unless you specify a zero line (using chp or chds),
         #       the min_value of a bar chart is always 0.
@@ -235,7 +248,7 @@ class Gchart
       @dataset
     end
   end
-  
+
   # Sets of data to handle multiple sets
   def datasets
     datasets = []
@@ -248,7 +261,7 @@ class Gchart
     end
     datasets
   end
-  
+
   def self.jstize(string)
     # See http://github.com/mattetti/googlecharts/issues#issue/27
     #URI.escape( string ).gsub("%7C", "|")
@@ -313,7 +326,7 @@ class Gchart
   # The title size cannot be set without specifying a color.
   # A dark key will be used for the title color if no color is specified 
   def set_title
-    title_params = "chtt=#{title}"
+    title_params = "chtt=#{title}".gsub(/\|/,"\n")
     unless (title_color.nil? && title_size.nil? && title_alignment.nil?)
       title_params << "&chts=" + (color, size, alignment = (title_color || '454545'), title_size, (title_alignment.to_s[0,1] || 'c')).compact.join(',')
     end
@@ -460,6 +473,11 @@ class Gchart
     "chxt=#{axis_with_labels}"
   end
 
+  def set_custom_axis_with_labels
+    @custom_axis_with_labels = custom_axis_with_labels.join(',') if @custom_axis_with_labels.is_a?(Array)
+    "chxp=#{custom_axis_with_labels}"
+  end
+
   def set_axis_labels
     if axis_labels.is_a?(Array)
       if RUBY_VERSION.to_f < 1.9
@@ -510,6 +528,7 @@ class Gchart
     when 'line'      then "lc"
     when 'line_xy'   then "lxy"
     when 'pie_3d'    then "p3"
+    when 'pie_c'     then "pc"
     when 'pie'       then "p"
     when 'venn'      then "v"
     when 'scatter'   then "s"
@@ -519,7 +538,7 @@ class Gchart
     when 'radar'
       "r" + (curved? ? 's' : '')
     when 'bar'
-      "b" + (horizontal? ? "h" : "v") + (grouped? ? "g" : "s")
+      "b" + (horizontal? ? "h" : "v") + bar_presentation
     end
   end
 
@@ -530,7 +549,7 @@ class Gchart
     when 'stripes'  then 'ls'
     end
   end
-  
+
   def number_visible
     n = 0
     dataset.each do |mds|
@@ -543,7 +562,7 @@ class Gchart
     end
     ""
   end
-  
+
   # Turns input into an array of axis hashes, dependent on the chart type
   def convert_dataset(ds)
     if dimensions == 2
@@ -563,7 +582,7 @@ class Gchart
     end
     ds
   end
-  
+
   # just an alias
   def axis_set
     dataset
@@ -577,7 +596,7 @@ class Gchart
       value.nil? ? "_" : value
     end
   end
-  
+
   def convert_to_extended_value(number)
     if number.nil?
       '__'
@@ -586,7 +605,7 @@ class Gchart
       value.nil? ? "__" : value
     end
   end
-  
+
   def encode_scaled_dataset(chars, nil_char)
     dsets = []
     dataset.each do |ds|
@@ -655,6 +674,7 @@ class Gchart
   def query_builder(options="")
     query_params = instance_variables.sort.map do |var|
       case var.to_s
+
       when '@data'
         set_data unless data == []  
         # Set the graph size  
@@ -673,7 +693,7 @@ class Gchart
       when '@thickness'
         set_line_thickness
       when '@new_markers'
-          set_line_markers
+        set_line_markers
       when '@bg_color'
         set_colors
       when '@chart_color'
@@ -690,6 +710,8 @@ class Gchart
         set_range_markers
       when '@grid_lines'
         set_grid_lines
+      when '@custom_axis_with_labels'
+        set_custom_axis_with_labels
       when '@geographical_area'
         set_geographical_area
       when '@country_codes'
